@@ -50,6 +50,7 @@ Authors:
 #include "styles.h"
 #include "graphics.h"
 #include "vertical.h"
+#include "utf8_support.h"
 
 #define ARABIC_NUMBERING 0
 #define ALPHA_NUMBERING  1
@@ -257,7 +258,13 @@ void CmdBeginEnd(int code)
             CmdEndParagraph(0);
             CmdVspace(VSPACE_SMALL_SKIP);
             startParagraph("theorem", PARAGRAPH_FIRST);
-            fprintRTF("{\\b %s} {\\i ", str);
+            fprintRTF("{\\b ");
+            if (CurrentFontEncoding() == ENCODING_UTF8) {
+                putRtfUtf8StrEscaped(str);
+            } else {
+                putRtfStrEscaped(str);
+            }
+            fprintRTF("} {\\i ");
             PushBrace();
             if (option)
                 free(option);
@@ -1182,7 +1189,11 @@ void CmdVerbatim(int code)
         else if (true_code == VERBATIM_1 || true_code == VERBATIM_2) {
 
             show_string(5, verbatim_text, "verbatim");
-            putRtfStrEscaped(verbatim_text);
+            if (CurrentFontEncoding() == ENCODING_UTF8) {
+                putRtfUtf8StrEscaped(verbatim_text);
+            } else {
+                putRtfStrEscaped(verbatim_text);
+            }
         }
 
         free(verbatim_text);
